@@ -23,13 +23,14 @@ class Vuln:
     """
     This class prints all CVEs that the host might be vulnerable to and adds them to the JSON output
     """
-    def __init__(self, args: object, ptjsonlib: object, helpers: object, http_client: object, base_response: object) -> None:
+    def __init__(self, args: object, ptjsonlib: object, helpers: object, http_client: object, base_response: object, kbn: bool) -> None:
         self.args = args
         self.ptjsonlib = ptjsonlib
         self.helpers = helpers
         self.http_client = http_client
         self.base_response = base_response
         self.helpers.print_header(__TESTLABEL__)
+        self.kbn =kbn
 
 
     def _get_cvss_score(self, cve_data: dict) -> str:
@@ -102,6 +103,6 @@ class Vuln:
                     "OK",
                     not self.args.json, indent=4)
 
-def run(args, ptjsonlib, helpers, http_client, base_response):
+def run(args, ptjsonlib, helpers, http_client, base_response, kbn=False):
     """Entry point for running the Vuln test"""
-    Vuln(args, ptjsonlib, helpers, http_client, base_response).run()
+    Vuln(args, ptjsonlib, helpers, http_client, base_response, kbn).run()
