@@ -98,7 +98,8 @@ class PtElastic:
             ptjsonlib=self.ptjsonlib,
             helpers=self.helpers,
             http_client=self.http_client,
-            base_response=self.base_response
+            base_response=self.base_response,
+            kbn=False
         ).run()
         ptprint(" ", "TEXT", not self.args.json)
 
@@ -271,7 +272,8 @@ def get_help():
             ["-F", "--file",                    "</path/to/file>",  "File to read if host is vulnerable to CVE-2015-5531 (default /etc/passwd)"],
             ["-di", "--dump-index"              "<index1, index2, ...>",      "Specify index to dump with data_dump module"],
             ["-df", "--dump-field",             "<field1,field2, field3.subfield>",     "Specify fields to dump with data_dump module"],
-            ["-o", "--output",                "<filename>",       "Specify the name of the file to store structure/data dump to"]
+            ["-o", "--output",                "<filename>",       "Specify the name of the file to store structure/data dump to"],
+            ["-b", "--built-in", "", "Enumerate/dump built-in Elasticsearch indexes"]
         ]
         }]
 
@@ -322,7 +324,8 @@ def parse_args() -> argparse.Namespace:
     parser.add_argument("-F", "--file",            type=str, default="/etc/passwd")
     parser.add_argument("-di", "--dump-index",     type=lambda f: f.split(","), default="")
     parser.add_argument("-df", "--dump-field",     type=lambda f: f.split(","), default=None)
-    parser.add_argument("-o", "--output",        type=lambda o: f"{o}.json", default=None)
+    parser.add_argument("-o", "--output",        type=lambda o: f"{o}.json" if "json" not in o else o, default=None)
+    parser.add_argument("-b", "--built-in", action="store_true")
     if len(sys.argv) == 1 or "-h" in sys.argv or "--help" in sys.argv:
         ptprint(help_print(get_help(), SCRIPTNAME, __version__))
         sys.exit(0)
